abort

Macro abort 

macro_rules! abort {
    ($dry:expr) => { ... };
    ($dry:expr, $reason:expr) => { ... };
}
Abort macro that sets the abort flag in DryContext

This macro should be used when an operation determines that continuing execution would be futile and should not trigger retries.

Usage

use ops_rs::{abort, DryContext, OpError};

fn example_op(dry: &mut DryContext) -> Result<(), OpError> {
    abort!(dry);
}