macro_rules! dry_get_key {
($ctx:expr, $key:expr) => { ... };
}Expand description
Retrieve a value from dry context using a custom key name
let var: Option
macro_rules! dry_get_key {
($ctx:expr, $key:expr) => { ... };
}Retrieve a value from dry context using a custom key name
let var: Option