op_wrapper

Macro op_wrapper 

macro_rules! op_wrapper {
    (unit $name:ident for $from:ty) => { ... };
    (last $name:ident for $elem:ty) => { ... };
}
Create a wrapper that converts any Op to Op using a conversion strategy For advanced composability between different op types Usage is typically not needed with the new flexible batch!/repeat!/repeat_until! macros