macro_rules! void_op {
($wrapper_name:ident, $op_type:ty) => { ... };
}Expand description
Macro to create a void wrapper type that discards the result
macro_rules! void_op {
($wrapper_name:ident, $op_type:ty) => { ... };
}Macro to create a void wrapper type that discards the result