Module ops

Module ops 

Functions

get_caller_trigger_name
Stack trace analysis to get caller class name Equivalent to Java getCallerCallerClassName()
perform
Central execution function with automatic logging wrapper Equivalent to Java OPS.perform() method
wrap_nested_exception
Wrap nested op exception without op name Equivalent to Java wrapNestedOpException(Exception)
wrap_nested_op_exception
Wrap nested op exception with context Equivalent to Java wrapNestedOpException(String, Exception)
wrap_runtime_exception
Convert any error to OpError with context Equivalent to Java wrapNestedRuntimeException(Exception)