pub struct LoopOp<T> { /* private fields */ }Expand description
Loop operation that executes a batch of operations repeatedly until a limit is reached
Implementations
Sourceimpl<T> LoopOp<T>where
T: Send + 'static,
impl<T> LoopOp<T>where
T: Send + 'static,
Sourcepub fn new(counter_var: String, limit: usize, ops: Vec<Arc<dyn Op<T>>>) -> Self
pub fn new(counter_var: String, limit: usize, ops: Vec<Arc<dyn Op<T>>>) -> Self
Create a new loop operation
Arguments
counter_var- Name of the counter variable to store in contextlimit- Maximum number of iterations to performops- Vector of operations to execute in each iteration
Sourcepub fn with_continue_on_error(self, continue_on_error: bool) -> Self
pub fn with_continue_on_error(self, continue_on_error: bool) -> Self
Set whether to continue on error