break_loop

Macro break_loop 

macro_rules! break_loop {
    ($dry:expr) => { ... };
}
Break loop macro that sets the break flag in DryContext

This macro should be used within loop operations to exit the entire loop immediately, similar to ‘break’ in a for loop.

Automatically targets the current loop context.

Usage

use ops::{break_loop, DryContext, OpError};

fn example_op(dry: &mut DryContext) -> Result<i32, OpError> {
    break_loop!(dry);
}