continue_loop

Macro continue_loop 

macro_rules! continue_loop {
    ($dry:expr) => { ... };
}
Continue loop macro that sets the continue flag in DryContext

This macro should be used within loop operations to skip the rest of the current iteration, similar to ‘continue’ in a for loop.

Automatically targets the current loop context.

Usage

use ops::{continue_loop, DryContext, OpError};

fn example_op(dry: &mut DryContext) -> Result<i32, OpError> {
    continue_loop!(dry);
}