pub trait Op<T>: Send + Sync {
// Required methods
fn perform<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
dry: &'life1 mut DryContext,
wet: &'life2 mut WetContext,
) -> Pin<Box<dyn Future<Output = OpResult<T>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn metadata(&self) -> OpMetadata;
// Provided method
fn rollback<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_dry: &'life1 mut DryContext,
_wet: &'life2 mut WetContext,
) -> Pin<Box<dyn Future<Output = OpResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait { ... }
}Required Methods
fn perform<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
dry: &'life1 mut DryContext,
wet: &'life2 mut WetContext,
) -> Pin<Box<dyn Future<Output = OpResult<T>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn metadata(&self) -> OpMetadata
Provided Methods
Sourcefn rollback<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_dry: &'life1 mut DryContext,
_wet: &'life2 mut WetContext,
) -> Pin<Box<dyn Future<Output = OpResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn rollback<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_dry: &'life1 mut DryContext,
_wet: &'life2 mut WetContext,
) -> Pin<Box<dyn Future<Output = OpResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Optional rollback method for ops that need custom cleanup logic. Default implementation is a no-op for backward compatibility. Called automatically by batch operations when a later op fails.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".